
# frozen_string_literal: true
namespace :hyrax do
  namespace :default_admin_set_for_workflow do
    desc "Create the Default Admin Set"
    task create: :environment do
      admin_role = Role.find_by(name: "admin")
      admin_user = admin_role&.users&.first

      if admin_user.present?
        rub_default_admin_set_title = ENV.fetch('RUB_ADMIN_SET_TITLE', 'RUB publication workflow')
        crc_default_admin_set_title = ENV.fetch('CRC_ADMIN_SET_TITLE', 'CRC 1280 Publishing Workflow')

        [rub_default_admin_set_title, crc_default_admin_set_title].each do |title|
          unless AdminSetHelper.find_admin_set_by_property(title: [title]).present?
            admin_set = Hyrax::AdministrativeSet.new(title: [title])
            updated_admin_set = Hyrax.persister.save(resource: admin_set)
            
            Hyrax::AdminSetCreateService.call(admin_set: updated_admin_set, creating_user: admin_user)

            workflow_name = title == rub_default_admin_set_title ? 'rub_publication_workflow' : 'crc_1280_publication_workflow'
            permission_template = Hyrax::PermissionTemplate.find_by(source_id: updated_admin_set.id.to_s)

            mediated_workflow = permission_template.available_workflows.where(name: workflow_name).first

            Sipity::Workflow.activate!(permission_template: permission_template, workflow_id: mediated_workflow.id)

            # Add Participants
            pub_manager = ENV.fetch('SYSTEM_PUBLICATION_MANAGER', 'publication_manager@hyrax')
            access_grants_params_for_manage = {access_grants_attributes:{'0'=> {agent_type: "user", agent_id: pub_manager, access:"manage"}}}
            if title == rub_default_admin_set_title
              access_grants_params_for_deposit = {access_grants_attributes:{'0'=> {agent_type: "group", agent_id: 'registered', access:"deposit"}}}
            else
              access_grants_params_for_deposit = {access_grants_attributes:{'0'=> {agent_type: "group", agent_id: 'crc_1280_member', access:"deposit"}}}
            end
            permission_template_form = Hyrax::Forms::PermissionTemplateForm.new(permission_template)
            permission_template_form.update(access_grants_params_for_manage)
            permission_template_form.update(access_grants_params_for_deposit)
            # Set visibility
            visibility_params = {
              release_period: Hyrax::PermissionTemplate::RELEASE_TEXT_VALUE_NO_DELAY,
              visibility: 'restricted'
            }
            permission_template_form.update(visibility_params)
          end
        end
      else
        puts "Admin Sets not created, No Admin user exists."
      end
    end
  end
end
